# [0.4.6](https://github.com/seriaati/hakushin-py/compare/v0.4.5..v0.4.6) - 2024-11-22

## Bug Fixes

-  [**breaking**]Change type of gi.New.character_ids to list[str | int] - ([998de19](https://github.com/seriaati/hakushin-py/commit/998de19d6638ad4ea81fd7728ee5b3fb0e106eb1))

## Continuous Integrations

- Configure workflows - ([34794a6](https://github.com/seriaati/hakushin-py/commit/34794a6e95f880f9024bfa5bff3e2d7e56481f44))

## Miscellaneous Chores

- Add .vscode/ to gitignore - ([5f40c04](https://github.com/seriaati/hakushin-py/commit/5f40c04ec85fd5403a311adc55a6579761888225))

